/*
	Copyright (C) 2020 n0n3m4 (Roman Lebedev)
	All rights reserved.
	Redistribution and use is allowed only by written personal permission of n0n3m4 (Roman Lebedev).
	Any other use is prohibited
*/

/*
	This file is a part of Backcompat library for Android.
*/

#ifndef BACKCOMPAT_UNISTD_H
#define BACKCOMPAT_UNISTD_H

#define execl __backcompat_orig_execl
#define execlp __backcompat_orig_execlp
#define execle __backcompat_orig_execle
#define execv __backcompat_orig_execv
#define execvp __backcompat_orig_execvp
#define execve __backcompat_orig_execve
#define execvpe __backcompat_orig_execvpe
#define fexecve __backcompat_orig_fexecve
#define readlink __backcompat_orig_readlink
#define vfork __backcompat_orig_vfork
#define chdir __backcompat_orig_chdir

#include_next <unistd.h>
// We have variadics here
#include <stdarg.h>

#undef execl
#undef execlp
#undef execle
#undef execv
#undef execvp
#undef execve
#undef execvpe
#undef fexecve
#undef readlink
#undef readlinkat
#undef vfork
#undef chdir

#define execl backcompat_execl
#define execlp backcompat_execlp
#define execle backcompat_execle
#define execv backcompat_execv
#define execvp backcompat_execvp
#define execve backcompat_execve
#define execvpe backcompat_execvpe
#define fexecve backcompat_fexecve
#define readlink backcompat_readlink
#define vfork backcompat_vfork
#define chdir backcompat_chdir

#ifndef __BEGIN_DECLS
#ifdef   __cplusplus
# define __BEGIN_DECLS  extern "C" {                                            
# define __END_DECLS }
#else
# define __BEGIN_DECLS
# define __END_DECLS
#endif
#endif

__BEGIN_DECLS

int execl(const char* path, const char* arg0, ...);
int execlp(const char* file, const char* arg0, ...);
int execle(const char* path, const char* arg0, ...);
int execv(const char* path, char* const* argv);
int execvp(const char* file, char* const* argv);
int execve(const char* file, char* const* argv, char* const* envp);
int execvpe(const char* file, char* const* argv, char* const* envp);
int fexecve(int fd, char* const* argv, char* const* envp);
ssize_t readlink(const char* path, char* buf, size_t bufsize);
pid_t vfork(void);
int chdir(const char* __path);

int backcompat_execl_va(const char* path, const char* arg0, va_list ap);
int backcompat_execlp_va(const char* file, const char* arg0, va_list ap);
int backcompat_execle_va(const char* path, const char* arg0, va_list ap);

#ifndef LIBBACKCOMPAT_BUILDING

#undef execl
#undef execlp
#undef execle
#undef execv
#undef execvp
#undef execve
#undef execvpe
#undef fexecve
#undef readlink
#undef readlinkat
#undef vfork
#undef chdir

static __inline__ int execl(const char* path, const char* arg0, ...)
{
	va_list ap;
	va_start(ap, arg0);
	int result = backcompat_execl_va(path, arg0, ap);
	va_end(ap);
	return result;
}

static __inline__ int execlp(const char* file, const char* arg0, ...)
{
	va_list ap;
	va_start(ap, arg0);
	int result = backcompat_execlp_va(file, arg0, ap);
	va_end(ap);
	return result;
}

static __inline__ int execle(const char* path, const char* arg0, ...)
{
	va_list ap;
	va_start(ap, arg0);
	int result = backcompat_execle_va(path, arg0, ap);
	va_end(ap);
	return result;
}

static __inline__ __attribute__((__always_inline__)) int execv(const char* path, char* const* argv)
{
	return backcompat_execv(path, argv);
}

static __inline__ __attribute__((__always_inline__)) int execvp(const char* file, char* const* argv)
{
	return backcompat_execvp(file, argv);
}

static __inline__ __attribute__((__always_inline__)) int execve(const char* file, char* const* argv, char* const* envp)
{
	return backcompat_execve(file, argv, envp);
}

static __inline__ __attribute__((__always_inline__)) int execvpe(const char* file, char* const* argv, char* const* envp)
{
	return backcompat_execvpe(file, argv, envp);
}

static __inline__ __attribute__((__always_inline__)) int fexecve(int fd, char* const* argv, char* const* envp)
{
	return backcompat_fexecve(fd, argv, envp);
}

static __inline__ __attribute__((__always_inline__)) ssize_t readlink(const char* path, char* buf, size_t bufsize)
{
	return backcompat_readlink(path, buf, bufsize);
}

static __inline__ __attribute__((__always_inline__)) pid_t vfork(void)
{
	return backcompat_vfork();
}

static __inline__ __attribute__((__always_inline__)) int chdir(const char* __path)
{
	return backcompat_chdir(__path);
}

#endif

__END_DECLS

#endif
